package SDL::ConfigData;
use strict;
my $arrayref = eval do {local $/; <DATA>}
  or die "Couldn't load ConfigData data: $@";
close DATA;
my ($config, $features, $auto_features) = @$arrayref;

sub config { $config->{$_[1]} }

sub set_config { $config->{$_[1]} = $_[2] }
sub set_feature { $features->{$_[1]} = 0+!!$_[2] }  # Constrain to 1 or 0

sub auto_feature_names { grep !exists $features->{$_}, keys %$auto_features }

sub feature_names {
  my @features = (keys %$features, auto_feature_names());
  @features;
}

sub config_names  { keys %$config }

sub write {
  my $me = __FILE__;

  # Can't use Module::Build::Dumper here because M::B is only a
  # build-time prereq of this module
  require Data::Dumper;

  my $mode_orig = (stat $me)[2] & 07777;
  chmod($mode_orig | 0222, $me); # Make it writeable
  open(my $fh, '+<', $me) or die "Can't rewrite $me: $!";
  seek($fh, 0, 0);
  while (<$fh>) {
    last if /^__DATA__$/;
  }
  die "Couldn't find __DATA__ token in $me" if eof($fh);

  seek($fh, tell($fh), 0);
  my $data = [$config, $features, $auto_features];
  print($fh 'do{ my '
	      . Data::Dumper->new([$data],['x'])->Purity(1)->Dump()
	      . '$x; }' );
  truncate($fh, tell($fh));
  close $fh;

  chmod($mode_orig, $me)
    or warn "Couldn't restore permissions on $me: $!";
}

sub feature {
  my ($package, $key) = @_;
  return $features->{$key} if exists $features->{$key};

  my $info = $auto_features->{$key} or return 0;

  # Under perl 5.005, each(%$foo) isn't working correctly when $foo
  # was reanimated with Data::Dumper and eval().  Not sure why, but
  # copying to a new hash seems to solve it.
  my %info = %$info;

  require Module::Build;  # XXX should get rid of this
  while (my ($type, $prereqs) = each %info) {
    next if $type eq 'description' || $type eq 'recommends';

    my %p = %$prereqs;  # Ditto here.
    while (my ($modname, $spec) = each %p) {
      my $status = Module::Build->check_installed_status($modname, $spec);
      if ((!$status->{ok}) xor ($type =~ /conflicts$/)) { return 0; }
      if ( ! eval "require $modname; 1" ) { return 0; }
    }
  }
  return 1;
}


=head1 NAME

SDL::ConfigData - Configuration for SDL

=head1 SYNOPSIS

  use SDL::ConfigData;
  $value = SDL::ConfigData->config('foo');
  $value = SDL::ConfigData->feature('bar');

  @names = SDL::ConfigData->config_names;
  @names = SDL::ConfigData->feature_names;

  SDL::ConfigData->set_config(foo => $new_value);
  SDL::ConfigData->set_feature(bar => $new_value);
  SDL::ConfigData->write;  # Save changes


=head1 DESCRIPTION

This module holds the configuration data for the C<SDL>
module.  It also provides a programmatic interface for getting or
setting that configuration data.  Note that in order to actually make
changes, you'll have to have write access to the C<SDL::ConfigData>
module, and you should attempt to understand the repercussions of your
actions.


=head1 METHODS

=over 4

=item config($name)

Given a string argument, returns the value of the configuration item
by that name, or C<undef> if no such item exists.

=item feature($name)

Given a string argument, returns the value of the feature by that
name, or C<undef> if no such feature exists.

=item set_config($name, $value)

Sets the configuration item with the given name to the given value.
The value may be any Perl scalar that will serialize correctly using
C<Data::Dumper>.  This includes references, objects (usually), and
complex data structures.  It probably does not include transient
things like filehandles or sockets.

=item set_feature($name, $value)

Sets the feature with the given name to the given boolean value.  The
value will be converted to 0 or 1 automatically.

=item config_names()

Returns a list of all the names of config items currently defined in
C<SDL::ConfigData>, or in scalar context the number of items.

=item feature_names()

Returns a list of all the names of features currently defined in
C<SDL::ConfigData>, or in scalar context the number of features.

=item auto_feature_names()

Returns a list of all the names of features whose availability is
dynamically determined, or in scalar context the number of such
features.  Does not include such features that have later been set to
a fixed value.

=item write()

Commits any changes from C<set_config()> and C<set_feature()> to disk.
Requires write access to the C<SDL::ConfigData> module.

=back


=head1 AUTHOR

C<SDL::ConfigData> was automatically created using C<Module::Build>.
C<Module::Build> was written by Ken Williams, but he holds no
authorship claim or copyright claim to the contents of C<SDL::ConfigData>.

=cut


__DATA__
do{ my $x = [
       {
         'libraries' => {
                          'SDL_gfx_framerate' => {
                                                   'lib' => 'SDL_gfx',
                                                   'define' => 'HAVE_SDL_GFX_FRAMERATE',
                                                   'header' => 'SDL_framerate.h'
                                                 },
                          'SDL_ttf' => {
                                         'define' => 'HAVE_SDL_TTF',
                                         'header' => 'SDL_ttf.h',
                                         'lib' => 'SDL_ttf'
                                       },
                          'SDL_gfx_rotozoom' => {
                                                  'header' => 'SDL_rotozoom.h',
                                                  'define' => 'HAVE_SDL_GFX_ROTOZOOM',
                                                  'lib' => 'SDL_gfx'
                                                },
                          'png' => {
                                     'define' => 'HAVE_PNG',
                                     'header' => 'png.h',
                                     'lib' => 'png'
                                   },
                          'SDL_gfx' => {
                                         'lib' => 'SDL_gfx',
                                         'header' => 'SDL_gfxPrimitives.h',
                                         'define' => 'HAVE_SDL_GFX'
                                       },
                          'SDL_image' => {
                                           'define' => 'HAVE_SDL_IMAGE',
                                           'header' => 'SDL_image.h',
                                           'lib' => 'SDL_image'
                                         },
                          'SDL_Pango' => {
                                           'define' => 'HAVE_SDL_PANGO',
                                           'header' => 'SDL_Pango.h',
                                           'lib' => 'SDL_Pango'
                                         },
                          'tiff' => {
                                      'define' => 'HAVE_TIFF',
                                      'header' => 'tiff.h',
                                      'lib' => 'tiff'
                                    },
                          'SDL' => {
                                     'lib' => 'SDL',
                                     'define' => 'HAVE_SDL',
                                     'header' => 'SDL.h'
                                   },
                          'SDL_gfx_primitives' => {
                                                    'define' => 'HAVE_SDL_GFX_PRIMITIVES',
                                                    'header' => 'SDL_gfxPrimitives.h',
                                                    'lib' => 'SDL_gfx'
                                                  },
                          'SDL_gfx_blitfunc' => {
                                                  'lib' => 'SDL_gfx',
                                                  'header' => 'SDL_gfxBlitFunc.h',
                                                  'define' => 'HAVE_SDL_GFX_BLITFUNC'
                                                },
                          'jpeg' => {
                                      'header' => 'jpeglib.h',
                                      'define' => 'HAVE_JPEG',
                                      'lib' => 'jpeg'
                                    },
                          'GLU' => {
                                     'header' => 'GL/glu.h',
                                     'define' => 'HAVE_GLU',
                                     'lib' => 'GLU'
                                   },
                          'SDL_mixer' => {
                                           'lib' => 'SDL_mixer',
                                           'header' => 'SDL_mixer.h',
                                           'define' => 'HAVE_SDL_MIXER'
                                         },
                          'smpeg' => {
                                       'header' => 'smpeg/smpeg.h',
                                       'define' => 'HAVE_SMPEG',
                                       'lib' => 'smpeg'
                                     },
                          'SDL_gfx_imagefilter' => {
                                                     'define' => 'HAVE_SDL_GFX_IMAGEFILTER',
                                                     'header' => 'SDL_imageFilter.h',
                                                     'lib' => 'SDL_gfx'
                                                   },
                          'GL' => {
                                    'lib' => 'GL',
                                    'define' => 'HAVE_GL',
                                    'header' => [
                                                  'GL/gl.h',
                                                  'GL/glext.h'
                                                ]
                                  }
                        },
         'SDL_lib_translate' => {
                                  'SDL::Rect' => [
                                                   'SDL'
                                                 ],
                                  'SDL::Joystick' => [
                                                       'SDL'
                                                     ],
                                  'SDL::AudioCVT' => [
                                                       'SDL'
                                                     ],
                                  'SDL::VideoInfo' => [
                                                        'SDL'
                                                      ],
                                  'SDL::CDTrack' => [
                                                      'SDL'
                                                    ],
                                  'SDL::RWOps' => [
                                                    'SDL'
                                                  ],
                                  'SDL::Mixer' => [
                                                    'SDL',
                                                    'SDL_mixer'
                                                  ],
                                  'SDL::Overlay' => [
                                                      'SDL'
                                                    ],
                                  'SDLx::LayerManager' => [
                                                            'SDL'
                                                          ],
                                  'SDL::Surface' => [
                                                      'SDL'
                                                    ],
                                  'SDL::TTF' => [
                                                  'SDL',
                                                  'SDL_ttf'
                                                ],
                                  'SDL::GFX::FPSManager' => [
                                                              'SDL',
                                                              'SDL_gfx'
                                                            ],
                                  'SDL::Mouse' => [
                                                    'SDL'
                                                  ],
                                  'SDL::GFX::Rotozoom' => [
                                                            'SDL',
                                                            'SDL_gfx'
                                                          ],
                                  'SDL::GFX::Framerate' => [
                                                             'SDL',
                                                             'SDL_gfx'
                                                           ],
                                  'SDL::Mixer::Groups' => [
                                                            'SDL',
                                                            'SDL_mixer'
                                                          ],
                                  'SDL::Mixer::Channels' => [
                                                              'SDL',
                                                              'SDL_mixer'
                                                            ],
                                  'SDL::Version' => [
                                                      'SDL'
                                                    ],
                                  'SDL::GFX::BlitFunc' => [
                                                            'SDL',
                                                            'SDL_gfx'
                                                          ],
                                  'SDLx::Controller::Timer' => [
                                                                 'SDL'
                                                               ],
                                  'SDLx::Surface' => [
                                                       'SDL',
                                                       'SDL_gfx'
                                                     ],
                                  'SDL::GFX::Primitives' => [
                                                              'SDL',
                                                              'SDL_gfx'
                                                            ],
                                  'SDLx::SFont' => [
                                                     'SDL',
                                                     'SDL_image'
                                                   ],
                                  'SDL::MultiThread' => [
                                                          'SDL'
                                                        ],
                                  'SDL::Audio' => [
                                                    'SDL'
                                                  ],
                                  'SDL::Cursor' => [
                                                     'SDL'
                                                   ],
                                  'SDL::Image' => [
                                                    'SDL',
                                                    'SDL_image'
                                                  ],
                                  'SDL::Pango::Context' => [
                                                             'SDL',
                                                             'SDL_Pango'
                                                           ],
                                  'SDL::Mixer::MixChunk' => [
                                                              'SDL',
                                                              'SDL_mixer'
                                                            ],
                                  'SDL::Pango' => [
                                                    'SDL',
                                                    'SDL_Pango'
                                                  ],
                                  'SDLx::Controller::State' => [
                                                                 'SDL'
                                                               ],
                                  'SDL::Time' => [
                                                   'SDL'
                                                 ],
                                  'SDL::TTF::Font' => [
                                                        'SDL',
                                                        'SDL_ttf'
                                                      ],
                                  'SDL::GFX' => [
                                                  'SDL',
                                                  'SDL_gfx'
                                                ],
                                  'SDL::Mixer::Effects' => [
                                                             'SDL',
                                                             'SDL_mixer'
                                                           ],
                                  'SDL::CD' => [
                                                 'SDL'
                                               ],
                                  'SDLx::Controller::Interface' => [
                                                                     'SDL'
                                                                   ],
                                  'SDL::Mixer::Music' => [
                                                           'SDL',
                                                           'SDL_mixer'
                                                         ],
                                  'SDL::GFX::ImageFilter' => [
                                                               'SDL',
                                                               'SDL_gfx'
                                                             ],
                                  'SDL_perl' => [
                                                  'SDL'
                                                ],
                                  'SDL::PixelFormat' => [
                                                          'SDL'
                                                        ],
                                  'SDL::Events' => [
                                                     'SDL'
                                                   ],
                                  'SDL::CDROM' => [
                                                    'SDL'
                                                  ],
                                  'SDL::Color' => [
                                                    'SDL'
                                                  ],
                                  'SDL::Mixer::MixMusic' => [
                                                              'SDL',
                                                              'SDL_mixer'
                                                            ],
                                  'SDL::Event' => [
                                                    'SDL'
                                                  ],
                                  'SDLx::Validate' => [
                                                        'SDL'
                                                      ],
                                  'SDL::Palette' => [
                                                      'SDL'
                                                    ],
                                  'SDL::AudioSpec' => [
                                                        'SDL'
                                                      ],
                                  'SDL::Video' => [
                                                    'SDL'
                                                  ],
                                  'SDL::Mixer::Samples' => [
                                                             'SDL',
                                                             'SDL_mixer'
                                                           ],
                                  'SDLx::Layer' => [
                                                     'SDL',
                                                     'SDL_image'
                                                   ]
                                },
         'SDL_cfg' => {
                        'Image' => {
                                     'links' => [
                                                  '-lSDL',
                                                  '-lSDL_image'
                                                ],
                                     'defines' => [
                                                    '-DHAVE_SDL',
                                                    '-DHAVE_SDL_IMAGE'
                                                  ],
                                     'libs' => {
                                                 'SDL_image' => 1,
                                                 'SDL' => 1
                                               }
                                   },
                        'SFont' => {
                                     'links' => [
                                                  '-lSDL',
                                                  '-lSDL_image'
                                                ],
                                     'defines' => [
                                                    '-DHAVE_SDL',
                                                    '-DHAVE_SDL_IMAGE'
                                                  ],
                                     'libs' => {
                                                 'SDL' => 1,
                                                 'SDL_image' => 1
                                               }
                                   },
                        'Joystick' => {
                                        'libs' => {
                                                    'SDL' => 1
                                                  },
                                        'links' => [
                                                     '-lSDL'
                                                   ],
                                        'defines' => [
                                                       '-DHAVE_SDL'
                                                     ]
                                      },
                        'Palette' => {
                                       'links' => [
                                                    '-lSDL'
                                                  ],
                                       'defines' => [
                                                      '-DHAVE_SDL'
                                                    ],
                                       'libs' => {
                                                   'SDL' => 1
                                                 }
                                     },
                        'TTF_Font' => {
                                        'defines' => [
                                                       '-DHAVE_SDL',
                                                       '-DHAVE_SDL_TTF'
                                                     ],
                                        'links' => [
                                                     '-lSDL',
                                                     '-lSDL_ttf'
                                                   ],
                                        'libs' => {
                                                    'SDL' => 1,
                                                    'SDL_ttf' => 1
                                                  }
                                      },
                        'SDL' => {
                                   'libs' => {
                                               'SDL' => 1
                                             },
                                   'links' => [
                                                '-lSDL'
                                              ],
                                   'defines' => [
                                                  '-DHAVE_SDL'
                                                ]
                                 },
                        'Event' => {
                                     'libs' => {
                                                 'SDL' => 1
                                               },
                                     'links' => [
                                                  '-lSDL'
                                                ],
                                     'defines' => [
                                                    '-DHAVE_SDL'
                                                  ]
                                   },
                        'Overlay' => {
                                       'links' => [
                                                    '-lSDL'
                                                  ],
                                       'defines' => [
                                                      '-DHAVE_SDL'
                                                    ],
                                       'libs' => {
                                                   'SDL' => 1
                                                 }
                                     },
                        'SurfaceX' => {
                                        'defines' => [
                                                       '-DHAVE_SDL',
                                                       '-DHAVE_SDL_GFX_PRIMITIVES'
                                                     ],
                                        'links' => [
                                                     '-lSDL',
                                                     '-lSDL_gfx'
                                                   ],
                                        'libs' => {
                                                    'SDL_gfx_primitives' => 1,
                                                    'SDL' => 1
                                                  }
                                      },
                        'StateX' => {
                                      'links' => [
                                                   '-lSDL'
                                                 ],
                                      'defines' => [
                                                     '-DHAVE_SDL'
                                                   ],
                                      'libs' => {
                                                  'SDL' => 1
                                                }
                                    },
                        'BlitFunc' => {
                                        'links' => [
                                                     '-lSDL',
                                                     '-lSDL_gfx'
                                                   ],
                                        'defines' => [
                                                       '-DHAVE_SDL',
                                                       '-DHAVE_SDL_GFX_BLITFUNC'
                                                     ],
                                        'libs' => {
                                                    'SDL' => 1,
                                                    'SDL_gfx_blitfunc' => 1
                                                  }
                                      },
                        'MixerChannels' => {
                                             'links' => [
                                                          '-lSDL',
                                                          '-lSDL_mixer'
                                                        ],
                                             'defines' => [
                                                            '-DHAVE_SDL',
                                                            '-DHAVE_SDL_MIXER'
                                                          ],
                                             'libs' => {
                                                         'SDL' => 1,
                                                         'SDL_mixer' => 1
                                                       }
                                           },
                        'LayerX' => {
                                      'libs' => {
                                                  'SDL_image' => 1,
                                                  'SDL' => 1
                                                },
                                      'links' => [
                                                   '-lSDL',
                                                   '-lSDL_image'
                                                 ],
                                      'defines' => [
                                                     '-DHAVE_SDL',
                                                     '-DHAVE_SDL_IMAGE'
                                                   ]
                                    },
                        'Audio' => {
                                     'defines' => [
                                                    '-DHAVE_SDL'
                                                  ],
                                     'links' => [
                                                  '-lSDL'
                                                ],
                                     'libs' => {
                                                 'SDL' => 1
                                               }
                                   },
                        'Mouse' => {
                                     'libs' => {
                                                 'SDL' => 1
                                               },
                                     'defines' => [
                                                    '-DHAVE_SDL'
                                                  ],
                                     'links' => [
                                                  '-lSDL'
                                                ]
                                   },
                        'Version' => {
                                       'libs' => {
                                                   'SDL' => 1
                                                 },
                                       'links' => [
                                                    '-lSDL'
                                                  ],
                                       'defines' => [
                                                      '-DHAVE_SDL'
                                                    ]
                                     },
                        'Primitives' => {
                                          'links' => [
                                                       '-lSDL',
                                                       '-lSDL_gfx'
                                                     ],
                                          'defines' => [
                                                         '-DHAVE_SDL',
                                                         '-DHAVE_SDL_GFX_PRIMITIVES'
                                                       ],
                                          'libs' => {
                                                      'SDL_gfx_primitives' => 1,
                                                      'SDL' => 1
                                                    }
                                        },
                        'MixerGroups' => {
                                           'libs' => {
                                                       'SDL' => 1,
                                                       'SDL_mixer' => 1
                                                     },
                                           'links' => [
                                                        '-lSDL',
                                                        '-lSDL_mixer'
                                                      ],
                                           'defines' => [
                                                          '-DHAVE_SDL',
                                                          '-DHAVE_SDL_MIXER'
                                                        ]
                                         },
                        'CD' => {
                                  'libs' => {
                                              'SDL' => 1
                                            },
                                  'links' => [
                                               '-lSDL'
                                             ],
                                  'defines' => [
                                                 '-DHAVE_SDL'
                                               ]
                                },
                        'TTF' => {
                                   'links' => [
                                                '-lSDL',
                                                '-lSDL_ttf'
                                              ],
                                   'defines' => [
                                                  '-DHAVE_SDL',
                                                  '-DHAVE_SDL_TTF'
                                                ],
                                   'libs' => {
                                               'SDL_ttf' => 1,
                                               'SDL' => 1
                                             }
                                 },
                        'ValidateX' => {
                                         'defines' => [
                                                        '-DHAVE_SDL'
                                                      ],
                                         'links' => [
                                                      '-lSDL'
                                                    ],
                                         'libs' => {
                                                     'SDL' => 1
                                                   }
                                       },
                        'VideoInfo' => {
                                         'libs' => {
                                                     'SDL' => 1
                                                   },
                                         'defines' => [
                                                        '-DHAVE_SDL'
                                                      ],
                                         'links' => [
                                                      '-lSDL'
                                                    ]
                                       },
                        'MixerSamples' => {
                                            'libs' => {
                                                        'SDL' => 1,
                                                        'SDL_mixer' => 1
                                                      },
                                            'defines' => [
                                                           '-DHAVE_SDL',
                                                           '-DHAVE_SDL_MIXER'
                                                         ],
                                            'links' => [
                                                         '-lSDL',
                                                         '-lSDL_mixer'
                                                       ]
                                          },
                        'AudioSpec' => {
                                         'libs' => {
                                                     'SDL' => 1
                                                   },
                                         'defines' => [
                                                        '-DHAVE_SDL'
                                                      ],
                                         'links' => [
                                                      '-lSDL'
                                                    ]
                                       },
                        'CDROM' => {
                                     'defines' => [
                                                    '-DHAVE_SDL'
                                                  ],
                                     'links' => [
                                                  '-lSDL'
                                                ],
                                     'libs' => {
                                                 'SDL' => 1
                                               }
                                   },
                        'Time' => {
                                    'links' => [
                                                 '-lSDL'
                                               ],
                                    'defines' => [
                                                   '-DHAVE_SDL'
                                                 ],
                                    'libs' => {
                                                'SDL' => 1
                                              }
                                  },
                        'Pango' => {
                                     'libs' => {
                                                 'SDL' => 1,
                                                 'SDL_Pango' => 1
                                               },
                                     'links' => [
                                                  '-lSDL',
                                                  '-lSDL_Pango'
                                                ],
                                     'defines' => [
                                                    '-DHAVE_SDL',
                                                    '-DHAVE_SDL_PANGO'
                                                  ]
                                   },
                        'Rotozoom' => {
                                        'libs' => {
                                                    'SDL_gfx_rotozoom' => 1,
                                                    'SDL' => 1
                                                  },
                                        'defines' => [
                                                       '-DHAVE_SDL',
                                                       '-DHAVE_SDL_GFX_ROTOZOOM'
                                                     ],
                                        'links' => [
                                                     '-lSDL',
                                                     '-lSDL_gfx'
                                                   ]
                                      },
                        'AudioCVT' => {
                                        'libs' => {
                                                    'SDL' => 1
                                                  },
                                        'defines' => [
                                                       '-DHAVE_SDL'
                                                     ],
                                        'links' => [
                                                     '-lSDL'
                                                   ]
                                      },
                        'InterfaceX' => {
                                          'links' => [
                                                       '-lSDL'
                                                     ],
                                          'defines' => [
                                                         '-DHAVE_SDL'
                                                       ],
                                          'libs' => {
                                                      'SDL' => 1
                                                    }
                                        },
                        'Surface' => {
                                       'links' => [
                                                    '-lSDL'
                                                  ],
                                       'defines' => [
                                                      '-DHAVE_SDL'
                                                    ],
                                       'libs' => {
                                                   'SDL' => 1
                                                 }
                                     },
                        'GFX' => {
                                   'defines' => [
                                                  '-DHAVE_SDL',
                                                  '-DHAVE_SDL_GFX_PRIMITIVES'
                                                ],
                                   'links' => [
                                                '-lSDL',
                                                '-lSDL_gfx'
                                              ],
                                   'libs' => {
                                               'SDL_gfx_primitives' => 1,
                                               'SDL' => 1
                                             }
                                 },
                        'Video' => {
                                     'defines' => [
                                                    '-DHAVE_SDL'
                                                  ],
                                     'links' => [
                                                  '-lSDL'
                                                ],
                                     'libs' => {
                                                 'SDL' => 1
                                               }
                                   },
                        'PixelFormat' => {
                                           'libs' => {
                                                       'SDL' => 1
                                                     },
                                           'links' => [
                                                        '-lSDL'
                                                      ],
                                           'defines' => [
                                                          '-DHAVE_SDL'
                                                        ]
                                         },
                        'Events' => {
                                      'libs' => {
                                                  'SDL' => 1
                                                },
                                      'links' => [
                                                   '-lSDL'
                                                 ],
                                      'defines' => [
                                                     '-DHAVE_SDL'
                                                   ]
                                    },
                        'MixChunk' => {
                                        'libs' => {
                                                    'SDL_mixer' => 1,
                                                    'SDL' => 1
                                                  },
                                        'links' => [
                                                     '-lSDL',
                                                     '-lSDL_mixer'
                                                   ],
                                        'defines' => [
                                                       '-DHAVE_SDL',
                                                       '-DHAVE_SDL_MIXER'
                                                     ]
                                      },
                        'MixerMusic' => {
                                          'libs' => {
                                                      'SDL_mixer' => 1,
                                                      'SDL' => 1
                                                    },
                                          'defines' => [
                                                         '-DHAVE_SDL',
                                                         '-DHAVE_SDL_MIXER'
                                                       ],
                                          'links' => [
                                                       '-lSDL',
                                                       '-lSDL_mixer'
                                                     ]
                                        },
                        'Framerate' => {
                                         'libs' => {
                                                     'SDL_gfx_framerate' => 1,
                                                     'SDL' => 1
                                                   },
                                         'links' => [
                                                      '-lSDL',
                                                      '-lSDL_gfx'
                                                    ],
                                         'defines' => [
                                                        '-DHAVE_SDL',
                                                        '-DHAVE_SDL_GFX_FRAMERATE'
                                                      ]
                                       },
                        'MixMusic' => {
                                        'links' => [
                                                     '-lSDL',
                                                     '-lSDL_mixer'
                                                   ],
                                        'defines' => [
                                                       '-DHAVE_SDL',
                                                       '-DHAVE_SDL_MIXER'
                                                     ],
                                        'libs' => {
                                                    'SDL_mixer' => 1,
                                                    'SDL' => 1
                                                  }
                                      },
                        'MultiThread' => {
                                           'libs' => {
                                                       'SDL' => 1
                                                     },
                                           'links' => [
                                                        '-lSDL'
                                                      ],
                                           'defines' => [
                                                          '-DHAVE_SDL'
                                                        ]
                                         },
                        'ImageFilter' => {
                                           'defines' => [
                                                          '-DHAVE_SDL',
                                                          '-DHAVE_SDL_GFX_IMAGEFILTER'
                                                        ],
                                           'links' => [
                                                        '-lSDL',
                                                        '-lSDL_gfx'
                                                      ],
                                           'libs' => {
                                                       'SDL_gfx_imagefilter' => 1,
                                                       'SDL' => 1
                                                     }
                                         },
                        'Rect' => {
                                    'libs' => {
                                                'SDL' => 1
                                              },
                                    'links' => [
                                                 '-lSDL'
                                               ],
                                    'defines' => [
                                                   '-DHAVE_SDL'
                                                 ]
                                  },
                        'LayerManagerX' => {
                                             'libs' => {
                                                         'SDL' => 1
                                                       },
                                             'defines' => [
                                                            '-DHAVE_SDL'
                                                          ],
                                             'links' => [
                                                          '-lSDL'
                                                        ]
                                           },
                        'MixerEffects' => {
                                            'defines' => [
                                                           '-DHAVE_SDL',
                                                           '-DHAVE_SDL_MIXER'
                                                         ],
                                            'links' => [
                                                         '-lSDL',
                                                         '-lSDL_mixer'
                                                       ],
                                            'libs' => {
                                                        'SDL_mixer' => 1,
                                                        'SDL' => 1
                                                      }
                                          },
                        'Mixer' => {
                                     'links' => [
                                                  '-lSDL',
                                                  '-lSDL_mixer'
                                                ],
                                     'defines' => [
                                                    '-DHAVE_SDL',
                                                    '-DHAVE_SDL_MIXER'
                                                  ],
                                     'libs' => {
                                                 'SDL_mixer' => 1,
                                                 'SDL' => 1
                                               }
                                   },
                        'Context' => {
                                       'libs' => {
                                                   'SDL_Pango' => 1,
                                                   'SDL' => 1
                                                 },
                                       'links' => [
                                                    '-lSDL',
                                                    '-lSDL_Pango'
                                                  ],
                                       'defines' => [
                                                      '-DHAVE_SDL',
                                                      '-DHAVE_SDL_PANGO'
                                                    ]
                                     },
                        'TimerX' => {
                                      'libs' => {
                                                  'SDL' => 1
                                                },
                                      'links' => [
                                                   '-lSDL'
                                                 ],
                                      'defines' => [
                                                     '-DHAVE_SDL'
                                                   ]
                                    },
                        'CDTrack' => {
                                       'links' => [
                                                    '-lSDL'
                                                  ],
                                       'defines' => [
                                                      '-DHAVE_SDL'
                                                    ],
                                       'libs' => {
                                                   'SDL' => 1
                                                 }
                                     },
                        'RWOps' => {
                                     'defines' => [
                                                    '-DHAVE_SDL'
                                                  ],
                                     'links' => [
                                                  '-lSDL'
                                                ],
                                     'libs' => {
                                                 'SDL' => 1
                                               }
                                   },
                        'Color' => {
                                     'libs' => {
                                                 'SDL' => 1
                                               },
                                     'defines' => [
                                                    '-DHAVE_SDL'
                                                  ],
                                     'links' => [
                                                  '-lSDL'
                                                ]
                                   },
                        'Cursor' => {
                                      'links' => [
                                                   '-lSDL'
                                                 ],
                                      'defines' => [
                                                     '-DHAVE_SDL'
                                                   ],
                                      'libs' => {
                                                  'SDL' => 1
                                                }
                                    },
                        'FPSManager' => {
                                          'links' => [
                                                       '-lSDL',
                                                       '-lSDL_gfx'
                                                     ],
                                          'defines' => [
                                                         '-DHAVE_SDL',
                                                         '-DHAVE_SDL_GFX_FRAMERATE'
                                                       ],
                                          'libs' => {
                                                      'SDL_gfx_framerate' => 1,
                                                      'SDL' => 1
                                                    }
                                        }
                      },
         'subsystems' => {
                           'MixerEffects' => {
                                               'file' => {
                                                           'to' => 'lib/SDL/Mixer/Effects.xs',
                                                           'from' => 'src/Mixer/Effects.xs'
                                                         },
                                               'libraries' => [
                                                                'SDL',
                                                                'SDL_mixer'
                                                              ]
                                             },
                           'Mixer' => {
                                        'file' => {
                                                    'from' => 'src/Mixer/Mixer.xs',
                                                    'to' => 'lib/SDL/Mixer.xs'
                                                  },
                                        'libraries' => [
                                                         'SDL',
                                                         'SDL_mixer'
                                                       ]
                                      },
                           'ImageFilter' => {
                                              'libraries' => [
                                                               'SDL',
                                                               'SDL_gfx_imagefilter'
                                                             ],
                                              'file' => {
                                                          'to' => 'lib/SDL/GFX/ImageFilter.xs',
                                                          'from' => 'src/GFX/ImageFilter.xs'
                                                        }
                                            },
                           'LayerManagerX' => {
                                                'file' => {
                                                            'to' => 'lib/SDLx/LayerManager.xs',
                                                            'from' => 'src/SDLx/LayerManager.xs'
                                                          },
                                                'libraries' => [
                                                                 'SDL'
                                                               ]
                                              },
                           'Rect' => {
                                       'file' => {
                                                   'to' => 'lib/SDL/Rect.xs',
                                                   'from' => 'src/Core/objects/Rect.xs'
                                                 },
                                       'libraries' => [
                                                        'SDL'
                                                      ]
                                     },
                           'Color' => {
                                        'libraries' => [
                                                         'SDL'
                                                       ],
                                        'file' => {
                                                    'from' => 'src/Core/objects/Color.xs',
                                                    'to' => 'lib/SDL/Color.xs'
                                                  }
                                      },
                           'Cursor' => {
                                         'libraries' => [
                                                          'SDL'
                                                        ],
                                         'file' => {
                                                     'to' => 'lib/SDL/Cursor.xs',
                                                     'from' => 'src/Core/objects/Cursor.xs'
                                                   }
                                       },
                           'RWOps' => {
                                        'file' => {
                                                    'to' => 'lib/SDL/RWOps.xs',
                                                    'from' => 'src/Core/objects/RWOps.xs'
                                                  },
                                        'libraries' => [
                                                         'SDL'
                                                       ]
                                      },
                           'CDTrack' => {
                                          'libraries' => [
                                                           'SDL'
                                                         ],
                                          'file' => {
                                                      'to' => 'lib/SDL/CDTrack.xs',
                                                      'from' => 'src/Core/objects/CDTrack.xs'
                                                    }
                                        },
                           'FPSManager' => {
                                             'file' => {
                                                         'from' => 'src/GFX/FPSManager.xs',
                                                         'to' => 'lib/SDL/GFX/FPSManager.xs'
                                                       },
                                             'libraries' => [
                                                              'SDL',
                                                              'SDL_gfx_framerate'
                                                            ]
                                           },
                           'Context' => {
                                          'file' => {
                                                      'to' => 'lib/SDL/Pango/Context.xs',
                                                      'from' => 'src/Pango/objects/Context.xs'
                                                    },
                                          'libraries' => [
                                                           'SDL',
                                                           'SDL_Pango'
                                                         ]
                                        },
                           'TimerX' => {
                                         'libraries' => [
                                                          'SDL'
                                                        ],
                                         'file' => {
                                                     'to' => 'lib/SDLx/Controller/Timer.xs',
                                                     'from' => 'src/SDLx/Timer.xs'
                                                   }
                                       },
                           'InterfaceX' => {
                                             'file' => {
                                                         'to' => 'lib/SDLx/Controller/Interface.xs',
                                                         'from' => 'src/SDLx/Controller/Interface.xs'
                                                       },
                                             'libraries' => [
                                                              'SDL'
                                                            ]
                                           },
                           'AudioCVT' => {
                                           'libraries' => [
                                                            'SDL'
                                                          ],
                                           'file' => {
                                                       'to' => 'lib/SDL/AudioCVT.xs',
                                                       'from' => 'src/Core/objects/AudioCVT.xs'
                                                     }
                                         },
                           'Rotozoom' => {
                                           'file' => {
                                                       'to' => 'lib/SDL/GFX/Rotozoom.xs',
                                                       'from' => 'src/GFX/Rotozoom.xs'
                                                     },
                                           'libraries' => [
                                                            'SDL',
                                                            'SDL_gfx_rotozoom'
                                                          ]
                                         },
                           'Surface' => {
                                          'libraries' => [
                                                           'SDL'
                                                         ],
                                          'file' => {
                                                      'to' => 'lib/SDL/Surface.xs',
                                                      'from' => 'src/Core/objects/Surface.xs'
                                                    }
                                        },
                           'CDROM' => {
                                        'libraries' => [
                                                         'SDL'
                                                       ],
                                        'file' => {
                                                    'from' => 'src/Core/CDROM.xs',
                                                    'to' => 'lib/SDL/CDROM.xs'
                                                  }
                                      },
                           'Pango' => {
                                        'file' => {
                                                    'from' => 'src/Pango/Pango.xs',
                                                    'to' => 'lib/SDL/Pango.xs'
                                                  },
                                        'libraries' => [
                                                         'SDL',
                                                         'SDL_Pango'
                                                       ]
                                      },
                           'Time' => {
                                       'file' => {
                                                   'from' => 'src/Core/Time.xs',
                                                   'to' => 'lib/SDL/Time.xs'
                                                 },
                                       'libraries' => [
                                                        'SDL'
                                                      ]
                                     },
                           'MultiThread' => {
                                              'file' => {
                                                          'from' => 'src/Core/MultiThread.xs',
                                                          'to' => 'lib/SDL/MultiThread.xs'
                                                        },
                                              'libraries' => [
                                                               'SDL'
                                                             ]
                                            },
                           'Video' => {
                                        'file' => {
                                                    'from' => 'src/Core/Video.xs',
                                                    'to' => 'lib/SDL/Video.xs'
                                                  },
                                        'libraries' => [
                                                         'SDL'
                                                       ]
                                      },
                           'GFX' => {
                                      'libraries' => [
                                                       'SDL',
                                                       'SDL_gfx_primitives'
                                                     ],
                                      'file' => {
                                                  'to' => 'lib/SDL/GFX.xs',
                                                  'from' => 'src/GFX/GFX.xs'
                                                }
                                    },
                           'MixMusic' => {
                                           'libraries' => [
                                                            'SDL',
                                                            'SDL_mixer'
                                                          ],
                                           'file' => {
                                                       'to' => 'lib/SDL/Mixer/MixMusic.xs',
                                                       'from' => 'src/Mixer/objects/MixMusic.xs'
                                                     }
                                         },
                           'Framerate' => {
                                            'libraries' => [
                                                             'SDL',
                                                             'SDL_gfx_framerate'
                                                           ],
                                            'file' => {
                                                        'to' => 'lib/SDL/GFX/Framerate.xs',
                                                        'from' => 'src/GFX/Framerate.xs'
                                                      }
                                          },
                           'PixelFormat' => {
                                              'file' => {
                                                          'from' => 'src/Core/objects/PixelFormat.xs',
                                                          'to' => 'lib/SDL/PixelFormat.xs'
                                                        },
                                              'libraries' => [
                                                               'SDL'
                                                             ]
                                            },
                           'MixerMusic' => {
                                             'libraries' => [
                                                              'SDL',
                                                              'SDL_mixer'
                                                            ],
                                             'file' => {
                                                         'from' => 'src/Mixer/Music.xs',
                                                         'to' => 'lib/SDL/Mixer/Music.xs'
                                                       }
                                           },
                           'MixChunk' => {
                                           'libraries' => [
                                                            'SDL',
                                                            'SDL_mixer'
                                                          ],
                                           'file' => {
                                                       'to' => 'lib/SDL/Mixer/MixChunk.xs',
                                                       'from' => 'src/Mixer/objects/MixChunk.xs'
                                                     }
                                         },
                           'Events' => {
                                         'file' => {
                                                     'from' => 'src/Core/Events.xs',
                                                     'to' => 'lib/SDL/Events.xs'
                                                   },
                                         'libraries' => [
                                                          'SDL'
                                                        ]
                                       },
                           'Primitives' => {
                                             'libraries' => [
                                                              'SDL',
                                                              'SDL_gfx_primitives'
                                                            ],
                                             'file' => {
                                                         'to' => 'lib/SDL/GFX/Primitives.xs',
                                                         'from' => 'src/GFX/Primitives.xs'
                                                       }
                                           },
                           'Version' => {
                                          'libraries' => [
                                                           'SDL'
                                                         ],
                                          'file' => {
                                                      'to' => 'lib/SDL/Version.xs',
                                                      'from' => 'src/Core/objects/Version.xs'
                                                    }
                                        },
                           'MixerGroups' => {
                                              'file' => {
                                                          'from' => 'src/Mixer/Groups.xs',
                                                          'to' => 'lib/SDL/Mixer/Groups.xs'
                                                        },
                                              'libraries' => [
                                                               'SDL',
                                                               'SDL_mixer'
                                                             ]
                                            },
                           'MixerSamples' => {
                                               'libraries' => [
                                                                'SDL',
                                                                'SDL_mixer'
                                                              ],
                                               'file' => {
                                                           'to' => 'lib/SDL/Mixer/Samples.xs',
                                                           'from' => 'src/Mixer/Samples.xs'
                                                         }
                                             },
                           'AudioSpec' => {
                                            'libraries' => [
                                                             'SDL'
                                                           ],
                                            'file' => {
                                                        'from' => 'src/Core/objects/AudioSpec.xs',
                                                        'to' => 'lib/SDL/AudioSpec.xs'
                                                      }
                                          },
                           'VideoInfo' => {
                                            'file' => {
                                                        'from' => 'src/Core/objects/VideoInfo.xs',
                                                        'to' => 'lib/SDL/VideoInfo.xs'
                                                      },
                                            'libraries' => [
                                                             'SDL'
                                                           ]
                                          },
                           'ValidateX' => {
                                            'libraries' => [
                                                             'SDL'
                                                           ],
                                            'file' => {
                                                        'from' => 'src/SDLx/Validate.xs',
                                                        'to' => 'lib/SDLx/Validate.xs'
                                                      }
                                          },
                           'CD' => {
                                     'libraries' => [
                                                      'SDL'
                                                    ],
                                     'file' => {
                                                 'from' => 'src/Core/objects/CD.xs',
                                                 'to' => 'lib/SDL/CD.xs'
                                               }
                                   },
                           'TTF' => {
                                      'libraries' => [
                                                       'SDL',
                                                       'SDL_ttf'
                                                     ],
                                      'file' => {
                                                  'to' => 'lib/SDL/TTF.xs',
                                                  'from' => 'src/TTF/TTF.xs'
                                                }
                                    },
                           'TTF_Font' => {
                                           'file' => {
                                                       'to' => 'lib/SDL/TTF/Font.xs',
                                                       'from' => 'src/TTF/objects/Font.xs'
                                                     },
                                           'libraries' => [
                                                            'SDL',
                                                            'SDL_ttf'
                                                          ]
                                         },
                           'SDL' => {
                                      'file' => {
                                                  'from' => 'src/SDL.xs',
                                                  'to' => 'lib/SDL_perl.xs'
                                                },
                                      'libraries' => [
                                                       'SDL'
                                                     ]
                                    },
                           'Image' => {
                                        'libraries' => [
                                                         'SDL',
                                                         'SDL_image'
                                                       ],
                                        'file' => {
                                                    'from' => 'src/Image.xs',
                                                    'to' => 'lib/SDL/Image.xs'
                                                  }
                                      },
                           'SFont' => {
                                        'file' => {
                                                    'from' => 'src/SDLx/SFont.xs',
                                                    'to' => 'lib/SDLx/SFont.xs'
                                                  },
                                        'libraries' => [
                                                         'SDL',
                                                         'SDL_image'
                                                       ]
                                      },
                           'Joystick' => {
                                           'file' => {
                                                       'to' => 'lib/SDL/Joystick.xs',
                                                       'from' => 'src/Core/Joystick.xs'
                                                     },
                                           'libraries' => [
                                                            'SDL'
                                                          ]
                                         },
                           'Palette' => {
                                          'libraries' => [
                                                           'SDL'
                                                         ],
                                          'file' => {
                                                      'to' => 'lib/SDL/Palette.xs',
                                                      'from' => 'src/Core/objects/Palette.xs'
                                                    }
                                        },
                           'LayerX' => {
                                         'libraries' => [
                                                          'SDL',
                                                          'SDL_image'
                                                        ],
                                         'file' => {
                                                     'to' => 'lib/SDLx/Layer.xs',
                                                     'from' => 'src/SDLx/Layer.xs'
                                                   }
                                       },
                           'Audio' => {
                                        'file' => {
                                                    'from' => 'src/Core/Audio.xs',
                                                    'to' => 'lib/SDL/Audio.xs'
                                                  },
                                        'libraries' => [
                                                         'SDL'
                                                       ]
                                      },
                           'Mouse' => {
                                        'libraries' => [
                                                         'SDL'
                                                       ],
                                        'file' => {
                                                    'from' => 'src/Core/Mouse.xs',
                                                    'to' => 'lib/SDL/Mouse.xs'
                                                  }
                                      },
                           'MixerChannels' => {
                                                'file' => {
                                                            'from' => 'src/Mixer/Channels.xs',
                                                            'to' => 'lib/SDL/Mixer/Channels.xs'
                                                          },
                                                'libraries' => [
                                                                 'SDL',
                                                                 'SDL_mixer'
                                                               ]
                                              },
                           'StateX' => {
                                         'libraries' => [
                                                          'SDL'
                                                        ],
                                         'file' => {
                                                     'from' => 'src/SDLx/Controller/State.xs',
                                                     'to' => 'lib/SDLx/Controller/State.xs'
                                                   }
                                       },
                           'Overlay' => {
                                          'libraries' => [
                                                           'SDL'
                                                         ],
                                          'file' => {
                                                      'from' => 'src/Core/objects/Overlay.xs',
                                                      'to' => 'lib/SDL/Overlay.xs'
                                                    }
                                        },
                           'BlitFunc' => {
                                           'libraries' => [
                                                            'SDL',
                                                            'SDL_gfx_blitfunc'
                                                          ],
                                           'file' => {
                                                       'from' => 'src/GFX/BlitFunc.xs',
                                                       'to' => 'lib/SDL/GFX/BlitFunc.xs'
                                                     }
                                         },
                           'Event' => {
                                        'file' => {
                                                    'from' => 'src/Core/objects/Event.xs',
                                                    'to' => 'lib/SDL/Event.xs'
                                                  },
                                        'libraries' => [
                                                         'SDL'
                                                       ]
                                      },
                           'SurfaceX' => {
                                           'file' => {
                                                       'from' => 'src/SDLx/Surface.xs',
                                                       'to' => 'lib/SDLx/Surface.xs'
                                                     },
                                           'libraries' => [
                                                            'SDL',
                                                            'SDL_gfx_primitives'
                                                          ]
                                         }
                         }
       },
       {},
       {}
     ];
$x; }